package com.ynet.life.file.parser;

import com.ynet.gene.data.KeyedCollection;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Iterator;
import java.util.List;
import org.dom4j.Document;
import org.dom4j.DocumentHelper;
import org.dom4j.Element;
import org.dom4j.io.OutputFormat;
import org.dom4j.io.XMLWriter;

/* loaded from: com_ynet_life_file_parser.jar:com/ynet/life/file/parser/CommonXMLFileWithTotalParser.class */
public class CommonXMLFileWithTotalParser implements CommonFileParserWithTotalInterface {
    private static final String ELEMENT_ROOT = "Root";
    private static final String ELEMENT_RECORD_ROOT = "RecordList";
    private static final String ELEMENT_RECORD = "Record";
    private static final String ELEMENT_TOTAL_ROOT = "Summary";
    private static final String ELEMENT_TOTAL_ELEMENT1 = "SumRecords";
    private static final String ELEMENT_TOTAL_ELEMENT2 = "SumMoney";

    @Override // com.ynet.life.file.parser.CommonFileParserWithTotalInterface
    public void writeToFile(List titles, List recordList, List outputFields, List outputFormats, List total, String filePathName, String encoding) throws TranFailException {
        XMLWriter writer = null;
        FileOutputStream file = null;
        try {
            try {
                file = new FileOutputStream(filePathName);
                OutputFormat format = new OutputFormat("\t", true, encoding);
                XMLWriter xMLWriter = new XMLWriter(file, format);
                writer = xMLWriter;
                xMLWriter.write(createDocument(recordList, titles, outputFields, outputFormats, total));
                try {
                    writer.close();
                    file.close();
                } catch (IOException ex) {
                    Trace.logError("LifeFile", "I/O异常", ex);
                    throw new TranFailException("EBLN0000", "I/O异常", ex);
                }
            } catch (Throwable th) {
                if (writer != null) {
                    try {
                        writer.close();
                    } catch (IOException ex2) {
                        Trace.logError("LifeFile", "I/O异常", ex2);
                        throw new TranFailException("EBLN0000", "I/O异常", ex2);
                    }
                }
                if (file != null) {
                    file.close();
                }
                throw th;
            }
        } catch (IOException ex3) {
            Trace.logError("LifeFile", "文件写入失败", ex3);
            throw new TranFailException("EBLN0000", "文件写入失败", ex3);
        }
    }

    private Document createDocument(List recordList, List titles, List outputFields, List outputFormats, List total) {
        Document document = DocumentHelper.createDocument();
        Element root = document.addElement(ELEMENT_ROOT);
        Element totalRoot = root.addElement(ELEMENT_TOTAL_ROOT);
        Element totalElement1 = totalRoot.addElement(ELEMENT_TOTAL_ELEMENT1);
        Element totalElement2 = totalRoot.addElement(ELEMENT_TOTAL_ELEMENT2);
        if (total != null && total.size() == 2) {
            totalElement1.addText((String) total.get(0));
            totalElement2.addText((String) total.get(1));
        }
        Element recordRoot = root.addElement(ELEMENT_RECORD_ROOT);
        if (titles.size() > 0) {
            Element recordElement = recordRoot.addElement(ELEMENT_RECORD);
            for (int i = 0; i < titles.size(); i++) {
                String title = (String) titles.get(i);
                String field = (String) outputFields.get(i);
                recordElement.addElement(field).addText(title);
            }
        }
        Iterator iterator = recordList.iterator();
        while (iterator.hasNext()) {
            KeyedCollection record = (KeyedCollection) iterator.next();
            Element recordElement2 = recordRoot.addElement(ELEMENT_RECORD);
            for (int i2 = 0; i2 < outputFields.size(); i2++) {
                String fieldId = (String) outputFields.get(i2);
                String str = (String) record.get(fieldId);
                String fieldValue = str;
                if (str == null) {
                    fieldValue = "";
                }
                String format = (String) outputFormats.get(i2);
                recordElement2.addElement(fieldId).addText(FileParserUtil.transformFormat(fieldValue, format));
            }
        }
        return document;
    }
}
